<!-- ....................................................................... -->
<!-- XML Events Qname Module  .............................................. -->
<!-- file: xml-events-qname-1.mod

     This is XML Events - the Events Module for XML,
     a definition of access to the DOM events model.

     Copyright 2000-2002 W3C (MIT, INRIA, Keio), All Rights Reserved.

     This DTD module is identified by the PUBLIC and SYSTEM identifiers:

       PUBLIC "-//W3C//ENTITIES XML Events Qnames 1.0//EN"
       SYSTEM "xml-events-qname-1.mod"

     Revisions:
     (none)
     ....................................................................... -->

<!-- XML Events Qname (Qualified Name) Module

     This module is contained in two parts, labeled Section 'A' and 'B':

       Section A declares parameter entities to support namespace-
       qualified names, namespace declarations, and name prefixing
       for XML Events and extensions.

       Section B declares parameter entities used to provide
       namespace-qualified names for all XML Events element types:

         %listener.qname;   the xmlns-qualified name for <listener>
         ...

     XML Events extensions would create a module similar to this one.
     Included in the XML distribution is a template module
     ('template-qname-1.mod') suitable for this purpose.
-->

<!-- Section A: XML Events XML namespace Framework :::::::::::::::::::: -->

<!-- 1. Declare a %XML-EVENTS.prefixed; conditional section keyword, used
        to activate namespace prefixing. The default value should
        inherit '%NS.prefixed;' from the DTD driver, so that unless
        overridden, the default behaviour follows the overall DTD
        prefixing scheme.
-->
<!ENTITY % uri "CDATA" >

<!ENTITY % XML-EVENTS.NAMESP.prefixed "IGNORE" >
<!ENTITY % XML-EVENTS.prefixed "%XML-EVENTS.NAMESP.prefixed;" >

<!-- 2. Declare a parameter entity (eg., %XML-EVENTS.xmlns;) containing
        the URI reference used to identify the XML Events namespace
-->
<!ENTITY % XML-EVENTS.xmlns  "http://www.w3.org/2001/xml-events" >

<!-- 3. Declare parameter entities (eg., %XML.prefix;) containing
        the default namespace prefix string(s) to use when prefixing
        is enabled. This may be overridden in the DTD driver or the
        internal subset of an document instance. If no default prefix
        is desired, this may be declared as an empty string.

     NOTE: As specified in [XMLNAMES], the namespace prefix serves
     as a proxy for the URI reference, and is not in itself significant.
-->
<!ENTITY % XML-EVENTS.prefix  "ev" >

<!-- 4. Declare parameter entities (eg., %XML-EVENTS.pfx;) containing the
        colonized prefix(es) (eg., '%XML-EVENTS.prefix;:') used when
        prefixing is active, an empty string when it is not.
-->
<![%XML-EVENTS.prefixed;[
<!ENTITY % XML-EVENTS.pfx  "%XML-EVENTS.prefix;:" >
]]>
<!ENTITY % XML-EVENTS.pfx  "" >

<!-- declare qualified name extensions here ............ -->
<!ENTITY % xml-events-qname-extra.mod "" >
%xml-events-qname-extra.mod;

<!-- 5. The parameter entity %XML-EVENTS.xmlns.extra.attrib; may be
        redeclared to contain any non-XML Events namespace declaration
        attributes for namespaces embedded in XML. The default
        is an empty string.  XLink should be included here if used
        in the DTD.
-->
<!ENTITY % XML-EVENTS.xmlns.extra.attrib "" >

<!-- The remainder of Section A is only followed in XML-EVENTS, not extensions. -->

<!-- Declare a parameter entity namesp.decl.attrib; containing all XML namespace
     declarations used in the DTD, plus the xmlns declaration for XML-EVENTS,
     its form dependent on whether prefixing is active.
-->
<![%XML-EVENTS.prefixed;[
<!ENTITY % XML-EVENTS.NAMESP.decl.attrib
	"xmlns:%XML-EVENTS.prefix; %uri; #FIXED '%XML-EVENTS.xmlns;'
	%XML-EVENTS.xmlns.extra.attrib;"
>
]]>
<!ENTITY % XML-EVENTS.NAMESP.decl.attrib "%XML-EVENTS.xmlns.extra.attrib;" >

<!-- This is a placeholder for future XLink support. -->
<!ENTITY % XLINK.xmlns.attrib "" >

<!-- Declare a parameter entity %XML-EVENTS.NAMESP.decl.attrib; containing all XML
     XML-EVENTS.NAMESPace declaration attributes used by XML-EVENTS, including a default
     xmlns attribute when prefixing is inactive	     .
-->
<![%XML-EVENTS.prefixed;[
<!ENTITY % XML-EVENTS.xmlns.attrib
	"%XML-EVENTS.NAMESP.decl.attrib;
	 %XLINK.xmlns.attrib;"
>
]]>
<!ENTITY % XML-EVENTS.xmlns.attrib
	"xmlns		%uri;	#FIXED	'%XML-EVENTS.xmlns;'
	 %XLINK.xmlns.attrib;"
>	 	 

<!-- placeholder for qualified name redeclarations -->
<!ENTITY % XML-EVENTS-qname.redecl "" >
%XML-EVENTS-qname.redecl;

<!-- Section B: XML Qualified Names ::::::::::::::::::::::::::::: -->

<!-- 6. This section declares parameter entities used to provide
        XML-EVENTS.NAMESPace-qualified names for all XML Events element types.
-->

<!ENTITY % xml-events.listener.qname  "%XML-EVENTS.pfx;listener" >

<!-- The following defines a PE for use in the attribute sets of elements in
     other XML-EVENTS.NAMESPaces that want to incorporate the XML Event attributes. Note
     that in this case the XML-EVENTS.pfx should always be defined. -->

<!ENTITY % xml-events.event.qname "%XML-EVENTS.pfx;event" >
<!ENTITY % xml-events.observer.qname "%XML-EVENTS.pfx;observer" >
<!ENTITY % xml-events.target.qname "%XML-EVENTS.pfx;target" >
<!ENTITY % xml-events.handler.qname "%XML-EVENTS.pfx;handler" >
<!ENTITY % xml-events.phase.qname "%XML-EVENTS.pfx;phase" >
<!ENTITY % xml-events.propagate.qname "%XML-EVENTS.pfx;propagate" >
<!ENTITY % xml-events.defaultAction.qname "%XML-EVENTS.pfx;defaultAction" >

<!ENTITY % xml-events.attrs.qname
   "%xml-events.event.qname;         NMTOKEN      #IMPLIED
    %xml-events.observer.qname;      IDREF        #IMPLIED
    %xml-events.target.qname;        IDREF        #IMPLIED
    %xml-events.handler.qname;       %uri;    #IMPLIED
    %xml-events.phase.qname;         (capture|default) #IMPLIED
    %xml-events.propagate.qname;     (stop|continue)  #IMPLIED
    %xml-events.defaultAction.qname; (cancel|perform) #IMPLIED"
    >

<!-- end of xml-events-qname-1.mod --> 
